@@ -260,8 +260,8 @@ class sauserprefs extends rcube_plugin
             'sauserprefs.selectimportsource', 'import');
 
         // output table sorting prefs
-        $sorts = $this->rcube->config->get('sauserprefs_sort');
-        $sorts = json_decode($sorts, true);
+        $sorts = $this->rcube->config->get('sauserprefs_sort', '{}');
+        $sorts = is_string($sorts) ? json_decode($sorts, true) : [];
         if (!isset($sorts['#spam-langs-table'])) {
             $sorts['#spam-langs-table'] = [0, 'true'];
         }
@@ -498,9 +498,9 @@ class sauserprefs extends rcube_plugin
                     return $output;
                 };
 
-            $new_prefs = $translator($new_prefs);
-            $cur_prefs = $translator($cur_prefs);
-            $global_prefs = $translator($global_prefs);
+            $new_prefs = is_array($new_prefs) ? $translator($new_prefs) : $new_prefs;
+            $cur_prefs = is_array($cur_prefs) ? $translator($cur_prefs) : $cur_prefs;
+            $global_prefs = is_array($global_prefs) ? $translator($global_prefs) : $global_prefs;
         }
 
         return $this->storage->save_prefs($user_id, $new_prefs, $cur_prefs, $global_prefs);
@@ -842,7 +842,7 @@ class sauserprefs extends rcube_plugin
                 }
 
                 if (!isset($this->no_override['add_header all Level'])) {
-                    if ($this->user_prefs['remove_header all'] != 'Level') {
+                    if (!isset($this->user_prefs['remove_header all']) || $this->user_prefs['remove_header all'] != 'Level') {
                         $enabled = "1";
                         $char = $this->user_prefs['add_header all Level'];
                         $char = substr($char, 7, 1);
